//	+---------------------------+
//	|	Maze Generator			|
//	+---------------------------+
//	|	build.cs				|
//	+---------------------------+
//	|	Version: 1.0			|
//	|	Released: Jan.9.2014	|
//	|	Author: Zapk | 12270	|
//	+---------------------------+

if(!isObject(MazeClient))
{
	new GameConnection(MazeClient)
	{
		name = "Maze";
		bl_id = -12270;
		isAdmin = 1;
		isSuperAdmin = 1;
	};
}
if(!isObject(BrickGroup_Maze))
{
	new SimGroup(BrickGroup_Maze)
	{
		name = "Maze";
		bl_id = -12270;
		client = MazeClient;
	};
}
schedule(0, 0, eval, "MainBrickGroup.add(BrickGroup_Maze);");

function Maze_Create()
{
	echo("\c4Initializing maze creation...");
	BrickGroup_Maze.chainDeleteCallback = "Maze_CreatePhaseTwo();";
	BrickGroup_Maze.chainDeleteAll();
}

function Maze_CreatePhaseTwo()
{
	echo("\c4Generating maze...");
	Maze_Generate();
	
	%file = new fileObject();
	%file.openForRead($Maze::File);
	
	while(!%file.isEOF())
	{
		%line = %file.readLine();
		%mazeFile = trim(%mazeFile NL %line);
	}
	
	%file.close();
	%file.delete();
	
	echo("\c4Building maze...");
	for(%a = 0; %a <= ($Maze::Width * 2); %a++)
	{
		Maze_BuildPeice(0 SPC %a, %mazeFile);
		for(%b = 1; %b <= ($Maze::Height + 2); %b++)
		{
			Maze_BuildPeice(%b SPC %a, %mazeFile);
		}
	}
	
	echo("Maze creation complete.");
	announce("\c6Generated maze successfully.");
}

function Maze_BuildPeice(%xy, %mazeFile)
{
	%row = getWord(%xy, 0);
	%column = getWord(%xy, 1);
	
	%peice = getLine(%mazeFile, %row);
	%peice = getSubStr(%peice, %column, 1);
	
	if(%peice !$= "_" && %peice !$= "." && %peice !$= "|" && %peice !$= " ")
	{
		return;
	}
	else
	{
		Maze_PlantBrick(%xy SPC 0, Brick6x12fData, true, 5, 2, "0 0 1 90");
		Maze_PlantBrick(%xy SPC 16, Brick6x12fData, true, 5, 2, "0 0 1 90");
	}
	
	if(%peice $= "_")
	{
		Maze_PlantBrick(%xy SPC 1.66, Brick2x6x5Data, false, 6, 3, "0 0 1 0");
		Maze_PlantBrick(%xy SPC 1.66, Brick2x2x5Data, false, 6, 4, "0 0 1 0");
		Maze_PlantBrick(%xy SPC 1.66, Brick2x2x5Data, false, 6, 5, "0 0 1 0");
	}
	
	if(%peice $= ".")
	{
		Maze_PlantBrick(%xy SPC 1.66, Brick2x2x5Data, false, 5, 3, "0 0 1 0");
	}
	
	if(%peice $= "|")
	{
		Maze_PlantBrick(%xy SPC 1.66, Brick2x6x5Data, false, 6, 2, "0 0 1 90");
		Maze_PlantBrick(%xy SPC 1.66, Brick2x6x5Data, false, 6, 6, "0 0 1 90");
	}
}

function Maze_PlantBrick(%position, %datablock, %zlock, %colour, %forceType, %rotation)
{
	if(!isObject(%datablock))
	{
		return;
	}
	
	%posx = getWord(%position, 0);
	%posy = getWord(%position, 1);
	%posz = getWord(%position, 2);
	
	if(%forceType == 1)
	{
		%posx = brickToMetric(4 * %posx);
		%posy = brickToMetric(4 * %posy);
	}
	else if(%forceType == 2)
	{
		%posx = brickToMetric(12 * %posx);
		%posy = brickToMetric(6 * %posy);
	}
	else if(%forceType == 3)
	{
		%posx = brickToMetric(12 * %posx + 2);
		%posy = brickToMetric(6 * %posy);
	}
	else if(%forceType == 4)
	{
		%posx = brickToMetric(12 * %posx + 2);
		%posy = brickToMetric(6 * %posy + 4);
	}
	else if(%forceType == 5)
	{
		%posx = brickToMetric(12 * %posx + 2);
		%posy = brickToMetric(6 * %posy - 4);
	}
	else if(%forceType == 6)
	{
		%posx = brickToMetric(12 * %posx - 6);
		%posy = brickToMetric(6 * %posy);
	}
	else
	{
		%posx = brickToMetric(%datablock.brickSizeX * %posx);
		%posy = brickToMetric(%datablock.brickSizeY * %posy);
	}
	
	if(%zlock)
	{
		%posz = %posz + 13;
		%posz = brickToMetric(%posz);
		%posz = %datablock.brickSizeZ * %posz / 2.50;
		%poszminus = %datablock.brickSizeZ * 2.50;
		%posz = %posz - %poszminus;
	}
	
	%brick = new fxDTSBrick()
	{
		datablock = %datablock;
		position = %posx SPC %posy SPC %posz;
		colorID = %colour;
		angleID = 0;
		isPlanted = 1;
		rotation = %rotation;
		stackBL_ID = 888888;
	};
	
	%brick.setTrusted(1);
	%brick.plant();
	BrickGroup_Maze.add(%brick);
}